@@ -17,7 +17,6 @@ use strict;
 #
 
 use Carp;
-use Log::Agent;
 
 ############################################################
 #
@@ -28,7 +27,7 @@ use Log::Agent;
 ############################################################
 sub new
 {
-    logconfess "deferred";
+    confess "deferred";
 }
 
 ############################################################
@@ -209,12 +208,12 @@ sub add_file_now
 ############################################################
 sub mime_type
 {
-    logconfess "deferred";
+    confess "deferred";
 }
 ############################################################
 sub _build_data
 {
-    logconfess "deferred";
+    confess "deferred";
 }
 
 #
@@ -364,28 +363,13 @@ Returns the data length.
 
 =back
 
-=head1 BUGS
-
-Please let me know about them.
-
-=head1 WEBSITE
-
-You can find information about CGI::Test and other related modules at:
-
-   http://cgi-test.sourceforge.net
-
-=head1 PUBLIC CVS SERVER
-
-CGI::Test now has a publicly accessible CVS server provided by
-SourceForge (www.sourceforge.net).  You can access it by going to:
-
-    http://sourceforge.net/cvs/?group_id=89570
-
 =head1 AUTHORS
 
-The original author is Raphael Manfredi F<E<lt>Raphael_Manfredi@pobox.comE<gt>>. 
+The original author is Raphael Manfredi.
 
-Send bug reports, hints, tips, suggestions to Steven Hilton at <mshiltonj@mshiltonj.com>
+Steven Hilton was long time maintainer of this module.
+
+Current maintainer is Alexander Tokarev F<E<lt>tokarev@cpan.orgE<gt>>.
 
 =head1 SEE ALSO
 
