@@ -14,10 +14,9 @@ use strict;
 # POST input data to be encoded with "application/x-www-form-urlencoded".
 #
 
-require CGI::Test::Input;
-use base qw(CGI::Test::Input);
+use Carp;
 
-use Log::Agent;
+use base qw(CGI::Test::Input);
 
 #
 # ->new
@@ -98,24 +97,13 @@ as C<application/x-www-form-urlencoded>.
 
 Please see L<CGI::Test::Input> for interface details.
 
-=head1 WEBSITE
-
-You can find information about CGI::Test and other related modules at:
-
-   http://cgi-test.sourceforge.net
-
-=head1 PUBLIC CVS SERVER
-
-CGI::Test now has a publicly accessible CVS server provided by
-SourceForge (www.sourceforge.net).  You can access it by going to:
-
-    http://sourceforge.net/cvs/?group_id=89570
-
 =head1 AUTHORS
 
-The original author is Raphael Manfredi F<E<lt>Raphael_Manfredi@pobox.comE<gt>>. 
+The original author is Raphael Manfredi.
 
-Send bug reports, hints, tips, suggestions to Steven Hilton at <mshiltonj@mshiltonj.com>
+Steven Hilton was long time maintainer of this module.
+
+Current maintainer is Alexander Tokarev F<E<lt>tokarev@cpan.orgE<gt>>.
 
 =head1 SEE ALSO
 
