@@ -16,8 +16,8 @@ use strict;
 # The page can be an error, or a real page, each with its own class hierarchy.
 #
 
-use Getargs::Long;
-use Log::Agent;
+use Carp;
+
 ######################################################################
 #
 # ->new
@@ -27,7 +27,7 @@ use Log::Agent;
 ######################################################################
 sub new
 {
-    logconfess "deferred";
+    confess "deferred";
 }
 
 #
@@ -224,24 +224,13 @@ authentication was made.
 
 =back
 
-=head1 WEBSITE
-
-You can find information about CGI::Test and other related modules at:
-
-   http://cgi-test.sourceforge.net
-
-=head1 PUBLIC CVS SERVER
-
-CGI::Test now has a publicly accessible CVS server provided by
-SourceForge (www.sourceforge.net).  You can access it by going to:
-
-    http://sourceforge.net/cvs/?group_id=89570
-
 =head1 AUTHORS
 
-The original author is Raphael Manfredi F<E<lt>Raphael_Manfredi@pobox.comE<gt>>. 
+The original author is Raphael Manfredi.
 
-Send bug reports, hints, tips, suggestions to Steven Hilton at <mshiltonj@mshiltonj.com>
+Steven Hilton was long time maintainer of this module.
+
+Current maintainer is Alexander Tokarev F<E<lt>tokarev@cpan.orgE<gt>>.
 
 =head1 SEE ALSO
 
